/*
 * Created on 16-Mar-2006
 * Created by Paul Gardner
 * Copyright (C) 2006 Aelitis, All Rights Reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 * 
 * AELITIS, SAS au capital de 46,603.30 euros
 * 8 Allee Lenotre, La Grille Royale, 78600 Le Mesnil le Roi, France.
 *
 */

package com.aelitis.azureus.core.speedmanager;

public interface 
SpeedManagerAdapter 
{
	public int
	getCurrentProtocolUploadSpeed();
	
	public int
	getCurrentDataUploadSpeed();
	
	public int
	getCurrentUploadLimit();
	
	public void
	setCurrentUploadLimit(
		int		bytes_per_second );
	
	public int
	getCurrentDownloadLimit();

	public void
	setCurrentDownloadLimit(
		int		bytes_per_second );
	
	public Object
	getLimits();
	
	public void
	setLimits(
		Object		limits,
		boolean		do_up,
		boolean		do_down );
}
